sphinxcontrib_websupport: Sphinx API for Web apps
=================================================

Description
-----------

sphinxcontrib-websupport provides a Python API to easily integrate
Sphinx documentation into your Web application.

License
-------

BSD
